@@ -15,8 +15,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <FreeNOS/System.h>
-#include <FreeNOS/Config.h>
 #include <Vector.h>
 #include <ExecutableFormat.h>
 #include <BootImage.h>
@@ -64,7 +62,7 @@ Size BootImageCreate::readBootSymbols(const char *conf_file,
     // Open configuration file
     if ((fp = fopen(conf_file, "r")) == NULL)
     {
-        fprintf(stderr, "%s: failed to open `%s': %s\n",
+        fprintf(stderr, "%s: failed to open `%s': %s\r\n",
                 prog, conf_file, strerror(errno));
         exit(EXIT_FAILURE);
     }
@@ -90,7 +88,7 @@ Size BootImageCreate::readBootSymbols(const char *conf_file,
             entry->symbol.type = BootData;
             symbolname = line + 9;
         } else {
-            fprintf(stderr, "%s: symbol type unknown in line: %s\n",
+            fprintf(stderr, "%s: symbol type unknown in line: %s\r\n",
                     prog, line);
             exit(EXIT_FAILURE);
         }
@@ -112,24 +110,24 @@ Size BootImageCreate::readBootSymbols(const char *conf_file,
         struct stat st;
         if (stat(symbolname, &st) == -1)
         {
-            fprintf(stderr, "%s: failed to stat `%s': %s\n",
+            fprintf(stderr, "%s: failed to stat `%s': %s\r\n",
                     prog, symbolname, strerror(errno));
             exit(EXIT_FAILURE);
         }
         // Allocate buffer
-        u8 *buffer = new u8[st.st_size];
+        entry->data = new u8[st.st_size];
 
         // Read the file
         FILE *entry_fd = fopen(symbolname, "r");
         if (!entry_fd)
         {
-            fprintf(stderr, "%s: failed to open `%s': %s\n",
+            fprintf(stderr, "%s: failed to open `%s': %s\r\n",
                     prog, symbolname, strerror(errno));
             exit(EXIT_FAILURE);
         }
-        if (fread(buffer, st.st_size, 1, entry_fd) != 1)
+        if (fread(entry->data, st.st_size, 1, entry_fd) != 1)
         {
-            fprintf(stderr, "%s: failed to fread `%s': %s\n",
+            fprintf(stderr, "%s: failed to fread `%s': %s\r\n",
                     prog, symbolname, strerror(errno));
             exit(EXIT_FAILURE);
         }
@@ -138,16 +136,16 @@ Size BootImageCreate::readBootSymbols(const char *conf_file,
         // Parse as BootProgram using libexec.
         if (entry->symbol.type == BootProgram || entry->symbol.type == BootPrivProgram)
         {
-            if (ExecutableFormat::find(buffer, st.st_size, &format) != ExecutableFormat::Success)
+            if (ExecutableFormat::find(entry->data, st.st_size, &format) != ExecutableFormat::Success)
             {
-                fprintf(stderr, "%s: failed to parse executable image format in `%s': %s\n",
+                fprintf(stderr, "%s: failed to parse executable image format in `%s': %s\r\n",
                             prog, symbolname, strerror(errno));
                 exit(EXIT_FAILURE);
             }
             // Extract memory regions
             if (format->regions(entry->regions, &num) != ExecutableFormat::Success || num <= 0)
             {
-                fprintf(stderr, "%s: failed to extract memory regions from `%s': %s\n",
+                fprintf(stderr, "%s: failed to extract memory regions from `%s': %s\r\n",
                             prog, symbolname, strerror(errno));
                 exit(EXIT_FAILURE);
             }
@@ -163,10 +161,11 @@ Size BootImageCreate::readBootSymbols(const char *conf_file,
             entry->numRegions  = 1;
             entry->regions[0].virt = 0;
             entry->regions[0].access = Memory::User | Memory::Readable | Memory::Writable;
-            entry->regions[0].size = st.st_size;
-            entry->regions[0].data = buffer;
+            entry->regions[0].dataSize = st.st_size;
+            entry->regions[0].memorySize = st.st_size;
+            entry->regions[0].dataOffset = 0;
         } else {
-            fprintf(stderr, "%s: unknown boot symbol type: %d\n",
+            fprintf(stderr, "%s: unknown boot symbol type: %d\r\n",
                     prog, (uint) entry->symbol.type);
             exit(EXIT_FAILURE);
         }
@@ -177,17 +176,17 @@ Size BootImageCreate::readBootSymbols(const char *conf_file,
         // Debug out memory sections
         for (Size i = 0; i < entry->numRegions; i++)
         {
-            printf("%s[%u]: vaddr=%x size=%u\n",
+            printf("%s[%u]: vaddr=%x size=%u\r\n",
                     symbolname, i, (uint) entry->regions[i].virt,
-                    entry->regions[i].size);
-            totalBytes += entry->regions[i].size;
+                    entry->regions[i].memorySize);
+            totalBytes += entry->regions[i].memorySize;
         }
     }
     // Close config file
     fclose(fp);
 
     // All done
-    printf("%d entries, %d bytes total\n", totalEntries, totalBytes);
+    printf("%d entries, %d bytes total\r\n", totalEntries, totalBytes);
     return totalEntries;
 }
 
@@ -208,7 +207,7 @@ BootImageCreate::Result BootImageCreate::exec()
     // Read boot symbols
     if (readBootSymbols(conf_file, prefix, &input) == 0)
     {
-        fprintf(stderr, "%s: failed to read boot symbols\n", prog);
+        fprintf(stderr, "%s: failed to read boot symbols\r\n", prog);
         return IOError;
     }
 
@@ -247,7 +246,7 @@ BootImageCreate::Result BootImageCreate::exec()
     // Point segment data after the segments table
     dataOffset  = image.segmentsTableOffset +
                   image.segmentsTableCount  * sizeof(BootSegment);
-    dataOffset += PAGESIZE - (dataOffset % PAGESIZE);
+    dataOffset += PageSize - (dataOffset % PageSize);
     
     // Fill the segments table by looping symbols
     for (Size i = 0; i < input.count(); i++)
@@ -257,7 +256,7 @@ BootImageCreate::Result BootImageCreate::exec()
         {
             // Fill in the segment
             segments[segCount].virtualAddress = input[i]->regions[j].virt;
-            segments[segCount].size           = input[i]->regions[j].size;
+            segments[segCount].size           = input[i]->regions[j].memorySize;
             segments[segCount].offset         = dataOffset;
             
             // Increment total segments size
@@ -266,7 +265,7 @@ BootImageCreate::Result BootImageCreate::exec()
             // Increment data pointer. Align on memory page boundary
             dataOffset += segments[i].size;
             lastDataOffset = dataOffset;
-            dataOffset += PAGESIZE - (dataOffset % PAGESIZE);
+            dataOffset += PageSize - (dataOffset % PageSize);
             segCount++;
         }
     }
@@ -276,7 +275,7 @@ BootImageCreate::Result BootImageCreate::exec()
     // Open boot image for writing
     if ((fp = fopen(out_file, "w")) == NULL)
     {
-        fprintf(stderr, "%s: failed to open `%s': %s\n",
+        fprintf(stderr, "%s: failed to open `%s': %s\r\n",
                 prog, out_file, strerror(errno));
         return IOError;
     }
@@ -286,7 +285,7 @@ BootImageCreate::Result BootImageCreate::exec()
         fwrite( symbols,  sizeof(BootSymbol)  * input.count(),  1, fp) <= 0 ||
         fwrite( segments, sizeof(BootSegment) * numSegments, 1, fp) <= 0)
     {
-        fprintf(stderr, "%s: failed to write BootImage headers to `%s': %s\n",
+        fprintf(stderr, "%s: failed to write BootImage headers to `%s': %s\r\n",
                 prog, out_file, strerror(errno));
         return IOError;
     }
@@ -301,16 +300,16 @@ BootImageCreate::Result BootImageCreate::exec()
             if (fseek(fp, segments[symbols[i].segmentsOffset].offset,
                       SEEK_SET) == -1)
             {
-                fprintf(stderr, "%s: failed to seek to BootSegment contents in `%s': %s\n",
+                fprintf(stderr, "%s: failed to seek to BootSegment contents in `%s': %s\r\n",
                         prog, out_file, strerror(errno));
                 return IOError;
             }
 
             // Write segment contents
-            if (fwrite(input[i]->regions[j].data,
-                       input[i]->regions[j].size, 1, fp) <= 0)
+            if (fwrite(input[i]->data + input[i]->regions[j].dataOffset,
+                       input[i]->regions[j].memorySize, 1, fp) <= 0)
             {
-                fprintf(stderr, "%s: failed to write BootSegment contents to `%s': %s\n",
+                fprintf(stderr, "%s: failed to write BootSegment contents to `%s': %s\r\n",
                         prog, out_file, strerror(errno));
                 return IOError;
             }
