@@ -47,7 +47,7 @@ class StdioCommand : public ShellCommand
      * @param params Array of parameters.
      * @return Error code or zero on success.
      */
-    virtual int execute(Size nparams, char **params);
+    virtual int execute(const Size nparams, const char **params);
 };
 
 /**
