@@ -21,6 +21,8 @@
 #include <Types.h>
 #include "ShellCommand.h"
 
+class Shell;
+
 /**
  * @addtogroup bin
  * @{
@@ -39,7 +41,7 @@ class TimeCommand : public ShellCommand
     /**
      * Constructor function.
      */
-    TimeCommand();
+    TimeCommand(Shell *shell);
 
     /**
      * Executes the command.
@@ -48,7 +50,12 @@ class TimeCommand : public ShellCommand
      * @param params Array of parameters.
      * @return Error code or zero on success.
      */
-    virtual int execute(Size nparams, char **params);
+    virtual int execute(const Size nparams, const char **params);
+
+  private:
+
+    /** Shell object */
+    Shell *m_shell;
 };
 
 /**
