@@ -8,10 +8,11 @@ stdio /dev/serial/serial0/io /dev/serial/serial0/io
 #
 # System Servers and Drivers.
 #
-#/server/usb/controller/server &
-#/server/usb/hub/server &
 /server/filesystem/tmp/server /tmp &
+/bin/mount --wait=/tmp
+
 /server/network/loopback/server &
+/bin/mount --wait=/network/loopback
 
 # This ensures we wait until all cores
 # are booted by the CoreServer.
