@@ -24,16 +24,16 @@
 #include <Log.h>
 #include "ProcessCtl.h"
 
-API::Result ProcessCtlHandler(ProcessID procID,
-                              ProcessOperation action,
-                              Address addr,
-                              Address output)
+API::Result ProcessCtlHandler(const ProcessID procID,
+                              const ProcessOperation action,
+                              const Address addr,
+                              const Address output)
 {
+    const Arch::MemoryMap map;
     Process *proc = ZERO;
     ProcessInfo *info = (ProcessInfo *) addr;
     ProcessManager *procs = Kernel::instance()->getProcessManager();
     Timer *timer;
-    Arch::MemoryMap map;
 
     DEBUG("#" << procs->current()->getID() << " " << action << " -> " << procID << " (" << addr << ")");
 
@@ -55,7 +55,7 @@ API::Result ProcessCtlHandler(ProcessID procID,
             ERROR("failed to create process");
             return API::IOError;
         }
-        return proc->getID();
+        return (API::Result) (API::Success | (proc->getID() << 16));
 
     case KillPID:
         procs->remove(proc, addr); // Addr contains the exit status
@@ -65,16 +65,44 @@ API::Result ProcessCtlHandler(ProcessID procID,
         break;
 
     case GetPID:
-        return procs->current()->getID();
+        return (API::Result) procs->current()->getID();
 
     case GetParent:
-        return procs->current()->getParent();
+        return (API::Result) procs->current()->getParent();
 
     case Schedule:
         procs->schedule();
         break;
 
+    case Stop:
+        if (procs->stop(proc) != ProcessManager::Success)
+        {
+            ERROR("failed to stop PID " << proc->getID());
+            return API::IOError;
+        }
+        if (procID == SELF)
+        {
+            procs->schedule();
+        }
+        break;
+
     case Resume:
+        if (procs->resume(proc) != ProcessManager::Success)
+        {
+            ERROR("failed to resume PID " << proc->getID());
+            return API::IOError;
+        }
+        break;
+
+    case Reset:
+        if (procs->reset(proc, addr) != ProcessManager::Success)
+        {
+            ERROR("failed to reset PID " << proc->getID());
+            return API::IOError;
+        }
+        break;
+
+    case Wakeup:
         // increment wakeup counter and set process ready
         if (procs->wakeup(proc) != ProcessManager::Success)
         {
@@ -122,7 +150,10 @@ API::Result ProcessCtlHandler(ProcessID procID,
         // For ARM, the kernel continues executing here even after
         // the schedule() is done. For ARM, the actual wait result is
         // injected directly in the saved CPU registers.
-        return procs->current()->getWaitResult();
+        //
+        // Note that the API::Result is stored in the lower 16-bit of the
+        // return value and the process exit status is stored in the upper 16 bits.
+        return (API::Result) ((API::Success) | (procs->current()->getWaitResult() << 16));
 
     case InfoTimer:
         if (!(timer = Kernel::instance()->getTimer()))
@@ -147,6 +178,7 @@ API::Result ProcessCtlHandler(ProcessID procID,
             procs->schedule();
         break;
     }
+
     return API::Success;
 }
 
@@ -166,7 +198,7 @@ Log & operator << (Log &log, ProcessOperation op)
         case InfoTimer: log.append("InfoTimer"); break;
         case EnterSleep: log.append("EnterSleep"); break;
         case Schedule:  log.append("Schedule"); break;
-        case Resume:    log.append("Resume"); break;
+        case Wakeup:    log.append("Wakeup"); break;
         default:        log.append("???"); break;
     }
     return log;
