@@ -15,8 +15,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __API_VMCTL_H
-#define __API_VMCTL_H
+#ifndef __KERNEL_API_VMCTL_H
+#define __KERNEL_API_VMCTL_H
 
 #include <Types.h>
 #include <Memory.h>
@@ -38,11 +38,13 @@ typedef enum MemoryOperation
     MapSparse,
     UnMap,
     Release,
+    ReleaseSections,
     LookupVirtual,
     Access,
     ReserveMem,
     AddMem,
     CacheClean,
+    CacheInvalidate,
     CacheCleanInvalidate
 }
 MemoryOperation;
@@ -56,10 +58,11 @@ MemoryOperation;
  *
  * @return API::Success on success and other API::ErrorCode on failure.
  */
-inline API::Result VMCtl(ProcessID procID, MemoryOperation op,
+inline API::Result VMCtl(const ProcessID procID,
+                         const MemoryOperation op,
                          Memory::Range *range = ZERO)
 {
-    return trapKernel3(API::VMCtlNumber, procID, op, (Address) range);
+    return (API::Result) trapKernel3(API::VMCtlNumber, procID, op, (Address) range);
 }
 
 /**
@@ -73,7 +76,18 @@ inline API::Result VMCtl(ProcessID procID, MemoryOperation op,
  * @{
  */
 
-extern API::Result VMCtlHandler(ProcessID procID, MemoryOperation op, Memory::Range *range);
+/**
+ * Kernel handler prototype. Examines and modifies virtual memory pages.
+ *
+ * @param procID Remote process.
+ * @param op Determines which operation to perform.
+ * @param range Describes the memory pages to operate on.
+ *
+ * @return API::Success on success and other API::ErrorCode on failure.
+ */
+extern API::Result VMCtlHandler(const ProcessID procID,
+                                const MemoryOperation op,
+                                Memory::Range *range);
 
 /**
  * @}
@@ -85,4 +99,4 @@ extern API::Result VMCtlHandler(ProcessID procID, MemoryOperation op, Memory::Ra
  * @}
  */
 
-#endif /* __API_VMCTL_H */
+#endif /* __KERNEL_API_VMCTL_H */
