@@ -15,8 +15,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __API_VMSHARE_H
-#define __API_VMSHARE_H
+#ifndef __KERNEL_API_VMSHARE_H
+#define __KERNEL_API_VMSHARE_H
 
 #include <FreeNOS/ProcessShares.h>
 #include <Types.h>
@@ -32,16 +32,17 @@
 /**
  * Prototype for user applications. Creates and removes shared virtual memory mappings.
  *
- * @param op Determines which operation to perform.
  * @param pid Remote process.
- * @param parameter Parameter for the operation.
- * @param size Size parameter for the operation.
+ * @param op Determines which operation to perform.
+ * @param share Pointer to the MemoryShare to use in the operation
  *
  * @return API::Success on success and other API::ErrorCode on failure.
  */
-inline API::Result VMShare(ProcessID pid, API::Operation op, ProcessShares::MemoryShare *share)
+inline API::Result VMShare(const ProcessID pid,
+                           const API::Operation op,
+                           ProcessShares::MemoryShare *share)
 {
-    return trapKernel3(API::VMShareNumber, pid, op, (Address) share);
+    return (API::Result) trapKernel3(API::VMShareNumber, pid, op, (Address) share);
 }
 
 /**
@@ -55,7 +56,18 @@ inline API::Result VMShare(ProcessID pid, API::Operation op, ProcessShares::Memo
  * @{
  */
 
-extern API::Result VMShareHandler(ProcessID pid, API::Operation op, ProcessShares::MemoryShare *share);
+/**
+ * Kernel handler prototype. Creates and removes shared virtual memory mappings.
+ *
+ * @param pid Remote process.
+ * @param op Determines which operation to perform.
+ * @param share Pointer to the MemoryShare to use in the operation
+ *
+ * @return API::Success on success and other API::ErrorCode on failure.
+ */
+extern API::Result VMShareHandler(const ProcessID pid,
+                                  const API::Operation op,
+                                  ProcessShares::MemoryShare *share);
 
 /**
  * @}
@@ -67,4 +79,4 @@ extern API::Result VMShareHandler(ProcessID pid, API::Operation op, ProcessShare
  * @}
  */
 
-#endif /* __API_VMSHARE_H */
+#endif /* __KERNEL_API_VMSHARE_H */
