@@ -31,6 +31,9 @@
 
 /**
  * Process which may execute on an Intel CPU.
+ *
+ * @todo IntelProcess currently has a per-process kernel stack, while the ARMProcess does not.
+ *       The kernel stack should not be needed anymore, and can be removed to reduce overhead.
  */
 class IntelProcess : public Process
 {
@@ -66,6 +69,13 @@ class IntelProcess : public Process
      */
     virtual Result initialize();
 
+    /**
+     * Restart execution at the given entry point.
+     *
+     * @param entry Address to begin execution.
+     */
+    virtual void reset(const Address entry);
+
     /**
      * Execute the process.
      *
