@@ -15,19 +15,26 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <Assert.h>
 #include <Macros.h>
+#include <MemoryBlock.h>
 #include "Allocator.h"
 
 Allocator * Allocator::m_default = ZERO;
 
+Allocator::Allocator()
+    : m_parent(ZERO)
+{
+    MemoryBlock::set(&m_range, 0, sizeof(m_range));
+}
+
 Allocator::Allocator(const Allocator::Range range)
     : m_parent(ZERO)
     , m_range(range)
 {
-    if (m_range.alignment == 0)
-    {
-        m_range.alignment = sizeof(u32);
-    }
+    assert(m_range.alignment >= sizeof(u32));
+    assert(m_range.size >= sizeof(u32));
+    assert((m_range.size % m_range.alignment) == 0);
 }
 
 Allocator::~Allocator()
