@@ -15,6 +15,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef __HOST__
+#include <FreeNOS/User.h>
+#endif /* __HOST__ */
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -27,10 +30,18 @@ StdioLog::StdioLog() : Log()
 
 void StdioLog::write(const char *str)
 {
-    ::write(1, str, strlen(str));
+    const ssize_t result = ::write(1, str, strlen(str));
+
+    // We do not really care about this result. Writing to standard
+    // output is either working or not. If this fails, a higher-level
+    // test and/or assert will catch the error.
+    (void) result;
 }
 
 void StdioLog::terminate() const
 {
+#ifndef __HOST__
+    PrivExec(Panic);
+#endif /* __HOST__ */
     ::exit(EXIT_FAILURE);
 }
