@@ -26,3 +26,18 @@ uint IntController::getBase() const
 {
     return m_base;
 }
+
+IntController::Result IntController::nextPending(uint & irq)
+{
+    return NotFound;
+}
+
+bool IntController::isTriggered(uint irq)
+{
+    return false;
+}
+
+IntController::Result IntController::send(const uint targetCoreId, const uint irq)
+{
+    return IOError;
+}
