@@ -21,6 +21,6 @@
 void clearBSS()
 {
     extern Address __bss_start, __bss_end;
-    Address bss_size = &__bss_end - &__bss_start;
+    const Address bss_size = (&__bss_end - &__bss_start) * sizeof(Address *);
     MemoryBlock::set(&__bss_start, 0, bss_size);
 }
