@@ -34,9 +34,6 @@
  * @{
  */
 
-/** Intel is little endian. */
-#define CPU_LITTLE_ENDIAN 1
-
 /** Protected Mode. */
 #define CR0_PE          0x00000001
 
