@@ -71,6 +71,13 @@ class IntelPaging : public MemoryContext
      */
     virtual ~IntelPaging();
 
+    /**
+     * Initialize the MemoryContext
+     *
+     * @return Result code
+     */
+    virtual Result initialize();
+
     /**
      * Activate the MemoryContext.
      *
@@ -108,7 +115,8 @@ class IntelPaging : public MemoryContext
     /**
      * Translate virtual address to physical address.
      *
-     * @param virt Virtual address to lookup on input, physical address on output.
+     * @param virt Virtual address to lookup
+     * @param phys Translated physical memory address on output
      *
      * @return Result code
      */
@@ -122,27 +130,31 @@ class IntelPaging : public MemoryContext
      *
      * @return Result code.
      */
-    virtual Result access(Address addr, Memory::Access *access) const;
+    virtual Result access(Address virt, Memory::Access *access) const;
 
     /**
-     * Release region of memory.
+     * Release memory sections.
      *
-     * @param region Memory region input
-     * @param tablesOnly Set to true to only release page tables and not mapped pages.
+     * Deallocate all associated physical memory
+     * which resides in the given memory section range.
      *
-     * @return Result code.
+     * @param range Range of memory sections to release
+     * @param tablesOnly True to only release associated page tables
+     *                   and do not release the actual mapped pages
+     *
+     * @return Result code
      */
-    virtual Result releaseRegion(MemoryMap::Region region, bool tablesOnly);
+    virtual Result releaseSection(const Memory::Range & range,
+                                  const bool tablesOnly = false);
 
     /**
      * Release range of memory.
      *
      * @param range Memory range input
-     * @param tablesOnly Set to true to only release page tables and not mapped pages.
      *
      * @return Result code.
      */
-    virtual Result releaseRange(Memory::Range *range, bool tablesOnly);
+    virtual Result releaseRange(Memory::Range *range);
 
   private:
 
