@@ -18,56 +18,65 @@
 #include <FreeNOS/User.h>
 #include "File.h"
 
-File::File(FileSystem::FileType type, UserID uid, GroupID gid)
-    : m_type(type)
+File::File(const u32 inode,
+           const FileSystem::FileType type,
+           const UserID uid,
+           const GroupID gid)
+    : m_inode(inode)
+    , m_type(type)
     , m_uid(uid)
     , m_gid(gid)
+    , m_access(FileSystem::OwnerRWX)
+    , m_size(0)
 {
-    m_access    = FileSystem::OwnerRWX;
-    m_size      = 0;
 }
 
 File::~File()
 {
 }
 
+u32 File::getInode() const
+{
+    return m_inode;
+}
+
 FileSystem::FileType File::getType() const
 {
     return m_type;
 }
 
-Error File::read(IOBuffer & buffer, Size size, Size offset)
+FileSystem::Result File::read(IOBuffer & buffer,
+                              Size & size,
+                              const Size offset)
 {
     return FileSystem::NotSupported;
 }
 
-Error File::write(IOBuffer & buffer, Size size, Size offset)
+FileSystem::Result File::write(IOBuffer & buffer,
+                               Size & size,
+                               const Size offset)
 {
     return FileSystem::NotSupported;
 }
 
-Error File::status(FileSystemMessage *msg)
+FileSystem::Result File::status(FileSystem::FileStat &st)
 {
-    FileSystem::FileStat st;
-    Error e;
-
-    // Fill in the status structure
     st.type     = m_type;
+    st.inode    = m_inode;
     st.access   = m_access;
     st.size     = m_size;
     st.userID   = m_uid;
     st.groupID  = m_gid;
-    st.deviceID.major = m_deviceId.major;
-    st.deviceID.minor = m_deviceId.minor;
 
-    // Copy to the remote process
-    if ((e = VMCopy(msg->from, API::Write, (Address) &st,
-                   (Address) msg->stat, sizeof(st)) > 0))
-    {
-        return FileSystem::Success;
-    }
-    else
-    {
-        return e;
-    }
+    return FileSystem::Success;
+}
+
+bool File::canRead() const
+{
+    return true;
+}
+
+bool File::canWrite() const
+{
+    return true;
 }
