@@ -38,11 +38,11 @@ typedef struct FileCache
      * @brief Constructor function.
      *
      * @param f File to insert into the cache.
-     * @param name Entry name of the File in the parent, if any.
+     * @param n Entry name of the File in the parent, if any.
      * @param p Our parent. ZERO if we have no parent.
      */
     FileCache(File *f, const char *n, FileCache *p)
-            : file(f), valid(true), parent(p)
+            : file(f), parent(p)
     {
         name = n;
 
@@ -61,9 +61,6 @@ typedef struct FileCache
     /** Contains childs. */
     HashTable<String, FileCache *> entries;
 
-    /** Is this entry still valid?. */
-    bool valid;
-
     /** Parent */
     FileCache *parent;
 }
