@@ -47,6 +47,13 @@ class FileStorage : public Storage
      */
     FileStorage(const char *path, Size offset = ZERO);
 
+    /**
+     * Initialize the Storage device
+     *
+     * @return Result code
+     */
+    virtual FileSystem::Result initialize();
+
     /**
      * Read a contiguous set of data.
      *
@@ -56,7 +63,7 @@ class FileStorage : public Storage
      *
      * @return Result code
      */
-    virtual FileSystem::Error read(u64 offset, void *buffer, Size size);
+    virtual FileSystem::Result read(const u64 offset, void *buffer, const Size size) const;
 
     /**
      * Write a contiguous set of data.
@@ -67,7 +74,7 @@ class FileStorage : public Storage
      *
      * @return Result code
      */
-    virtual FileSystem::Error write(u64 offset, void *buffer, Size size);
+    virtual FileSystem::Result write(const u64 offset, void *buffer, const Size size);
 
     /**
      * Retrieve maximum storage capacity.
@@ -81,6 +88,9 @@ class FileStorage : public Storage
     /** Path to the file */
     const char *m_path;
 
+    /** File descriptor of the file */
+    Size m_fd;
+
     /** Client for file system I/O */
     FileSystemClient m_file;
 
