@@ -28,53 +28,6 @@
  * @{
  */
 
-/** Number of bits needed to store a FileType. */
-#define FILETYPE_BITS   3
-
-/** Masker value for all FileTypes. */
-#define FILETYPE_MASK   7
-
-/**
- * Convert from a (host system's) POSIX struct stat into a FileType.
- *
- * @param st struct stat pointer.
- *
- * @return FileType value.
- */
-#define FILETYPE_FROM_ST(st) \
-({ \
-    FileSystem::FileType t = FileSystem::UnknownFile; \
-    \
-    switch ((st)->st_mode & S_IFMT) \
-    { \
-        case S_IFBLK:  t = FileSystem::BlockDeviceFile; break; \
-        case S_IFCHR:  t = FileSystem::CharacterDeviceFile; break; \
-        case S_IFIFO:  t = FileSystem::FIFOFile; break; \
-        case S_IFREG:  t = FileSystem::RegularFile; break; \
-        case S_IFDIR:  t = FileSystem::DirectoryFile; break; \
-        case S_IFLNK:  t = FileSystem::SymlinkFile; break; \
-        case S_IFSOCK: t = FileSystem::SocketFile; break; \
-        default: break; \
-    } \
-    t; \
-})
-
-/** Number of bits required for all FileModes. */
-#define FILEMODE_BITS 9
-
-/** Masker value for all FileMode values. */
-#define FILEMODE_MASK 0777
-
-/**
- * Converts an (host system's) POSIX struct st into a FileMode.
- *
- * @param st struct st pointer.
- *
- * @return FileMode value.
- */
-#define FILEMODE_FROM_ST(st) \
-    (FileSystem::FileMode)((st)->st_mode & FILEMODE_MASK)
-
 namespace FileSystem
 {
     /**
@@ -87,6 +40,7 @@ namespace FileSystem
         WriteFile,
         StatFile,
         DeleteFile,
+        WaitFile,
         MountFileSystem,
         WaitFileSystem,
         GetFileSystems
@@ -97,21 +51,19 @@ namespace FileSystem
      */
     enum Result
     {
-        Success          =  0,
-        InvalidArgument  = -1,
-        NotFound         = -2,
-        RetryAgain       = -3,
-        IOError          = -4,
-        PermissionDenied = -5,
-        AlreadyExists    = -6,
-        NotSupported     = -7,
-        RedirectRequest  = -8,
-        IpcError         = -9
+        Success = 0,
+        InvalidArgument,
+        NotFound,
+        RetryAgain,
+        IOError,
+        PermissionDenied,
+        AlreadyExists,
+        NotSupported,
+        RedirectRequest,
+        IpcError,
+        TimedOut
     };
 
-    /** May contain a byte count or Result code with an error. */
-    typedef slong Error;
-
     /**
      * All possible filetypes.
      */
@@ -160,12 +112,32 @@ namespace FileSystem
      */
     struct FileStat
     {
-        FileType type;      /**< File type. */
-        FileModes access;   /**< File access permission bits. */
-        Size size;          /**< Size of the file in bytes. */
-        UserID userID;      /**< User identity. */
-        GroupID groupID;    /**< Group identity. */
-        DeviceID deviceID;  /**< Device identity. */
+        FileType type;      /**@< File type. */
+        u32 inode;          /**@< Inode number */
+        ProcessID pid;      /**@< Process identifier of filesystem */
+        FileModes access;   /**@< File access permission bits. */
+        Size size;          /**@< Size of the file in bytes. */
+        UserID userID;      /**@< User identity. */
+        GroupID groupID;    /**@< Group identity. */
+    };
+
+    /**
+     * Provides information about an inode
+     */
+    struct WaitSet
+    {
+        u32 inode;     /**@< Inode number */
+        u16 requested; /**@< Requested status flags of the inode */
+        u16 current;   /**@< Indicates the currently active status flags */
+    };
+
+    /**
+     * WaitSet status flags
+     */
+    enum WaitStatus
+    {
+        Readable = (1 << 0), /**@< File can be read without blocking */
+        Writable = (1 << 1)  /**@< File can be written without blocking */
     };
 };
 
