@@ -34,7 +34,12 @@
  */
 
 /**
- * Client for using Channels.
+ * Client for using Channels on the local processor.
+ *
+ * @todo Intra-core communication is not yet supported by this client.
+ *       For intra-core channels, the local CoreServer should be contacted
+ *       which communicates with the remote CoreServer to properly setup
+ *       the channel between cores.
  */
 class ChannelClient : public StrictSingleton<ChannelClient>
 {
@@ -43,6 +48,9 @@ class ChannelClient : public StrictSingleton<ChannelClient>
     /** Maximum number of concurrent outgoing requests. */
     static const Size MaximumRequests = 32u;
 
+    /** Maximum number of retries for establishing new connection. */
+    static const Size MaxConnectRetries = 16u;
+
     /**
      * Holds an outgoing request
      */
@@ -222,6 +230,9 @@ class ChannelClient : public StrictSingleton<ChannelClient>
 
     /** Contains ongoing requests */
     Index<Request, MaximumRequests> m_requests;
+
+    /** Current Process ID */
+    const ProcessID m_pid;
 };
 
 /**
