@@ -15,42 +15,39 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <errno.h>
 #include "NetworkDevice.h"
 
-NetworkDevice::NetworkDevice(NetworkServer *server)
-    : Device(FileSystem::CharacterDeviceFile),
-      m_receive(1500),
-      m_transmit(1500)
+NetworkDevice::NetworkDevice(const u32 inode,
+                             NetworkServer &server)
+    : Device(inode, FileSystem::CharacterDeviceFile)
+    , m_maximumPacketSize(1500)
+    , m_receive(m_maximumPacketSize)
+    , m_transmit(m_maximumPacketSize)
+    , m_server(server)
+
 {
-    m_maximumPacketSize = 1500;
-    m_server = server;
-    m_eth = 0;
-    m_arp = 0;
-    m_ipv4 = 0;
-    m_udp = 0;
+    // Allocate protocols. Note that the FileSystemServer will take
+    // ownership of these objects via the FileCache hierarchy
+    m_eth = new Ethernet(m_server, *this);
+    m_arp = new ARP(m_server, *this, *m_eth);
+    m_ipv4 = new IPV4(m_server, *this, *m_eth);
+    m_icmp = new ICMP(m_server, *this, *m_ipv4);
+    m_udp = new UDP(m_server, *this, *m_ipv4);
 }
 
 NetworkDevice::~NetworkDevice()
 {
 }
 
-Error NetworkDevice::initialize()
+FileSystem::Result NetworkDevice::initialize()
 {
-    Error r = Device::initialize();
-    if (r != ESUCCESS)
+    const FileSystem::Result result = Device::initialize();
+    if (result != FileSystem::Success)
     {
-        ERROR("failed to initialize Device");
-        return r;
+        ERROR("failed to initialize Device: result = " << (int) result);
+        return result;
     }
 
-    // Setup protocol stack
-    m_eth  = new Ethernet(m_server, this);
-    m_arp  = new ARP(m_server, this);
-    m_ipv4 = new IPV4(m_server, this);
-    m_icmp = new ICMP(m_server, this);
-    m_udp  = new UDP(m_server, this);
-
     // Initialize protocols
     m_eth->initialize();
     m_arp->initialize();
@@ -62,14 +59,11 @@ Error NetworkDevice::initialize()
     m_eth->setIP(m_ipv4);
     m_eth->setARP(m_arp);
     m_arp->setIP(m_ipv4);
-    m_arp->setEthernet(m_eth);
     m_ipv4->setICMP(m_icmp);
     m_ipv4->setARP(m_arp);
-    m_ipv4->setEthernet(m_eth);
     m_ipv4->setUDP(m_udp);
-    m_icmp->setIP(m_ipv4);
-    m_udp->setIP(m_ipv4);
-    return r;
+
+    return FileSystem::Success;
 }
 
 const Size NetworkDevice::getMaximumPacketSize() const
@@ -87,11 +81,26 @@ NetworkQueue * NetworkDevice::getTransmitQueue()
     return &m_transmit;
 }
 
-Error NetworkDevice::process(NetworkQueue::Packet *pkt, Size offset)
+void NetworkDevice::unregisterSockets(const ProcessID pid)
+{
+    DEBUG("pid = " << pid);
+
+    m_udp->unregisterSockets(pid);
+    m_icmp->unregisterSockets(pid);
+}
+
+FileSystem::Result NetworkDevice::process(const NetworkQueue::Packet *pkt,
+                                          const Size offset)
 {
     DEBUG("");
 
     // Let the protocols process the packet
-    m_eth->process(pkt, offset);
-    return ESUCCESS;
+    return m_eth->process(pkt, offset);
+}
+
+FileSystem::Result NetworkDevice::startDMA()
+{
+    DEBUG("");
+
+    return FileSystem::Success;
 }
