@@ -24,6 +24,8 @@
 #include "Ethernet.h"
 #include "IPV4.h"
 
+class NetworkDevice;
+
 /**
  * @addtogroup lib
  * @{
@@ -49,10 +51,38 @@ class NetworkServer : public DeviceServer
      */
     virtual ~NetworkServer();
 
+    /**
+     * Register network device
+     *
+     * @param dev NetworkDevice pointer
+     */
+    void registerNetworkDevice(NetworkDevice *dev);
+
     /**
      * Initialize the NetworkServer.
+     *
+     * @return Result code
      */
     virtual FileSystem::Result initialize();
+
+    /**
+     * Called whenever another Process is terminated
+     *
+     * @param pid ProcessID of the terminating process
+     */
+    virtual void onProcessTerminated(const ProcessID pid);
+
+    /**
+     * Starts DMA on NetworkDevices after all pending requests are done
+     *
+     * @return True if retry is needed again, false if all requests processed
+     */
+    virtual bool retryRequests();
+
+  private:
+
+    /** Network device instance */
+    NetworkDevice *m_device;
 };
 
 /**
