@@ -29,8 +29,7 @@ int mkdir(const char *path, mode_t mode)
     // Ask FileSystem to create the file for us
     const FileSystem::Result result = filesystem.createFile(path,
                                                             FileSystem::DirectoryFile,
-                                                           (FileSystem::FileModes) (mode & FILEMODE_MASK),
-                                                            DeviceID());
+                                                           (FileSystem::FileModes) (mode & FILEMODE_MASK));
     // Set errno
     if (result == FileSystem::Success)
         errno = ESUCCESS;
