@@ -43,6 +43,11 @@ class TestInstance
      */
     TestInstance(const char *name);
 
+    /**
+     * Destructor
+     */
+    virtual ~TestInstance();
+
     /**
      * Retrieve test instance name
      *
