@@ -17,33 +17,15 @@
 
 #include <Factory.h>
 #include <KernelLog.h>
-#include <StdioLog.h>
-#include <Runtime.h>
-#include <fcntl.h>
-#include <unistd.h>
 #include "CoreServer.h"
 
 int main(int argc, char **argv)
 {
     KernelLog log;
     SystemInformation info;
-    const char *consolePath = "/dev/serial/serial0/io";
-    const char *consoleMount = "/dev/serial";
 
-    log.setMinimumLogLevel(Log::Notice);
-
-    // On the master core, wait for the serial device driver and re-open I/O
     if (info.coreId == 0)
     {
-        close(0);
-        close(1);
-        close(2);
-        waitMount(consoleMount);
-
-        while (open(consolePath, O_RDWR) == -1);
-        open(consolePath, O_RDWR);
-        open(consolePath, O_RDWR);
-
         NOTICE("initializing on core0");
     }
 
