@@ -39,8 +39,12 @@ class Loopback : public NetworkDevice
 
     /**
      * Constructor
+     *
+     * @param inode Inode number
+     * @param server NetworkServer reference
      */
-    Loopback(NetworkServer *server);
+    Loopback(const u32 inode,
+             NetworkServer &server);
 
     /**
      * Destructor
@@ -48,34 +52,36 @@ class Loopback : public NetworkDevice
     virtual ~Loopback();
 
     /**
-     * Perform initialization
+     * Initialize the device
+     *
+     * @return Result code
      */
-    virtual FileSystem::Error initialize();
+    virtual FileSystem::Result initialize();
 
     /**
      * Read ethernet address.
      *
      * @param address Ethernet address reference for output
      *
-     * @return FileSystem::Error code
+     * @return Result code
      */
-    virtual FileSystem::Error getAddress(Ethernet::Address *address);
+    virtual FileSystem::Result getAddress(Ethernet::Address *address);
 
     /**
      * Set ethernet address
      *
      * @param address New ethernet address to set
      *
-     * @return FileSystem::Error code
+     * @return Result code
      */
-    virtual FileSystem::Error setAddress(Ethernet::Address *address);
+    virtual FileSystem::Result setAddress(const Ethernet::Address *address);
 
     /**
      * Transmit one network packet
      *
      * @param pkt Network packet buffer
      */
-    virtual FileSystem::Error transmit(NetworkQueue::Packet *pkt);
+    virtual FileSystem::Result transmit(NetworkQueue::Packet *pkt);
 
   private:
 
