@@ -42,25 +42,29 @@ const char Keyboard::keymap[0x3a][2] =
     /*38*/{0x0, 0x0}, {' ', ' '}
 };
 
-Keyboard::Keyboard() : Device(FileSystem::CharacterDeviceFile), shiftState(ZERO)
+Keyboard::Keyboard(const u32 inode)
+    : Device(inode, FileSystem::CharacterDeviceFile)
+    , shiftState(ZERO)
 {
     m_identifier << "keyboard0";
 }
 
-FileSystem::Error Keyboard::initialize()
+FileSystem::Result Keyboard::initialize()
 {
     return FileSystem::Success;
 }
 
-FileSystem::Error Keyboard::interrupt(Size vector)
+FileSystem::Result Keyboard::interrupt(const Size vector)
 {
     pending = true;
     return FileSystem::Success;
 }
 
-FileSystem::Error Keyboard::read(IOBuffer & buffer, Size size, Size offset)
+FileSystem::Result Keyboard::read(IOBuffer & buffer,
+                                  Size & size,
+                                  const Size offset)
 {
-    FileSystem::Error ret = FileSystem::RetryAgain;
+    Size bytes = 0;
 
     // Do we have any new key events?
     if (pending)
@@ -81,11 +85,19 @@ FileSystem::Error Keyboard::read(IOBuffer & buffer, Size size, Size offset)
         {
             // Write to buffer
             buffer.write((void *) &keymap[keycode & 0x7f][shiftState], 1);
-            ret = 1;
+            bytes = 1;
         }
         // Re-enable interrupt
         ProcessCtl(SELF, EnableIRQ, PS2_IRQ);
     }
 
-    return ret;
+    if (bytes > 0)
+    {
+        size = bytes;
+        return FileSystem::Success;
+    }
+    else
+    {
+        return FileSystem::RetryAgain;
+    }
 }
